Stan Math Library: stan/math/fwd/scal/fun/expm1.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

expm1.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_EXPM1_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_EXPM1_HPP
3
4 #include <math.h>
5 #include <stan/math/fwd/core.hpp>
6 #include <cmath>
7
8 namespace stan {
9 namespace math {
10
11 template <typename T>
12 inline fvar<T> expm1(const fvar<T>& x) {
13 using std::exp;
14 using ::expm1;
15 return fvar<T>(expm1(x.val_), x.d_ * exp(x.val_));
16 }
17
18 }
19 }
20 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::expm1
var expm1(const stan::math::var &a)
The exponentiation of the specified variable minus 1 (C99).
Definition: expm1.hpp:57
stan::math::expm1
fvar< T > expm1(const fvar< T > &x)
Definition: expm1.hpp:12
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.